@@ -5,7 +5,7 @@ from .parser import ProtoParser
 
 
 def format_file(fp, indents=2, top_comment=False, align_by_equal_sign=False, flatten=False, comment_max_length=None,
-                new_fp=None):
+                new_fp=None, preview=False):
     """
     Format protobuf file, override the original file if no new file path(new_fp) specified
     or write the formatted result to a new file.
@@ -46,6 +46,7 @@ def format_file(fp, indents=2, top_comment=False, align_by_equal_sign=False, fla
          }
     :param comment_max_length: the max length of comment line, defalut is no limitation.
     :param new_fp: the file path of new formatted protobuf file. Rewrite the original file if it is not specified.
+    :param preview: preview formatted protobuf file with syntax highlighting, if it's true the new_fp will be overridden
     :return: file content size.
     """
     protobuf_obj = ProtoParser.load(fp=fp)
@@ -54,18 +55,21 @@ def format_file(fp, indents=2, top_comment=False, align_by_equal_sign=False, fla
         top_comment=top_comment,
         align_by_equal_sign=align_by_equal_sign,
         flatten=flatten,
-        comment_max_length=comment_max_length
+        comment_max_length=comment_max_length,
+        preview=preview
     )
 
-    if new_fp:
+    if new_fp and not preview:
         fp = new_fp
         if not os.path.exists(new_fp):
             path, tail = ntpath.split(new_fp)
             if not os.path.exists(path):
                 os.makedirs(path)
 
-    with open(fp, 'w') as f:
-        return f.write(content)
+    # if not preview, override the original file with formatted one.
+    if not preview:
+        with open(fp, 'w') as f:
+            return f.write(content)
 
 
 def format_str(proto_str, indents=2, top_comment=False, align_by_equal_sign=False, flatten=False,
