@@ -3,7 +3,7 @@ from wrap_enum import WrapEnum
 
 # https://developers.google.com/protocol-buffers/docs/proto3
 class BasicValueType(WrapEnum):
-    DOULBE = 'double'
+    DOUBLE = 'double'
     FLOAT = 'float'
     INT32 = 'int32'
     INT64 = 'int64'
